@@ -25,7 +25,6 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
 #include <gtk/gtk.h>
 
 #include "gst.h"
@@ -43,65 +42,92 @@ extern GstTool *tool;
 extern GtkWidget *users_table;
 extern GtkWidget *groups_table;
 
-GtkItemFactoryEntry users_popup_menu_items[] = {
-	{ N_("/_Add User ..."), NULL, G_CALLBACK (on_popup_add_activate), POPUP_ADD, "<StockItem>", GTK_STOCK_ADD },
-	{ "/", NULL, NULL, POPUP_SEPARATOR, "<Separator>", NULL },
-	{ N_("/_Properties"), NULL, G_CALLBACK (on_popup_settings_activate), POPUP_SETTINGS, "<StockItem>", GTK_STOCK_PROPERTIES },
-	{ N_("/_Delete"), NULL, G_CALLBACK (on_popup_delete_activate), POPUP_DELETE, "<StockItem>", GTK_STOCK_DELETE },
+GtkActionEntry popup_menu_items [] = {
+	{ "Add",         GTK_STOCK_ADD,        N_("_Add"),        NULL, NULL, G_CALLBACK (on_popup_add_activate)      },
+	{ "Properties",  GTK_STOCK_PROPERTIES, N_("_Properties"), NULL, NULL, G_CALLBACK (on_popup_settings_activate) },
+	{ "Delete",      GTK_STOCK_DELETE,     N_("_Delete"),     NULL, NULL, G_CALLBACK (on_popup_delete_activate)   }
 };
 
-GtkItemFactoryEntry groups_popup_menu_items[] = {
-	{ N_("/_Add group ..."), NULL, G_CALLBACK (on_popup_add_activate), POPUP_ADD, "<StockItem>", GTK_STOCK_ADD },
-	{ "/", NULL, NULL, POPUP_SEPARATOR, "<Separator>", NULL },
-	{ N_("/_Properties"), NULL, G_CALLBACK (on_popup_settings_activate), POPUP_SETTINGS, "<StockItem>", GTK_STOCK_PROPERTIES },
-	{ N_("/_Delete"), NULL, G_CALLBACK (on_popup_delete_activate), POPUP_DELETE, "<StockItem>", GTK_STOCK_DELETE },
-};
+const gchar *ui_description =
+	"<ui>"
+	"  <popup name='MainMenu'>"
+	"    <menuitem action='Add'/>"
+	"    <separator/>"
+	"    <menuitem action='Properties'/>"
+	"    <menuitem action='Delete'/>"
+	"  </popup>"
+	"</ui>";
 
-static gchar *
-item_factory_trans (const char *path, gpointer data)
+GtkWidget*
+popup_menu_create (GtkWidget *widget)
 {
-	return _((gchar*)path);
-}
+	GtkUIManager   *ui_manager;
+	GtkActionGroup *action_group;
+	GtkWidget      *popup;
 
-GtkItemFactory *
-popup_item_factory_create (GtkWidget *widget)
-{
-	GtkItemFactory *item_factory;
+	action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_add_actions (action_group, popup_menu_items, G_N_ELEMENTS (popup_menu_items), widget);
+
+	ui_manager = gtk_ui_manager_new ();
+	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+	if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL))
+		return NULL;
+
+	g_object_set_data (G_OBJECT (widget), "ui-manager", ui_manager);
+	popup = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
+
+	return popup;
 
-	item_factory = gtk_item_factory_new (GTK_TYPE_MENU, "<main>", NULL);
-	gtk_item_factory_set_translate_func (item_factory, item_factory_trans,
-					     NULL, NULL);
-	if (widget == users_table)
-		gtk_item_factory_create_items (item_factory, G_N_ELEMENTS (users_popup_menu_items),
-					       users_popup_menu_items, (gpointer) users_table);
-	else if (widget == groups_table)
-		gtk_item_factory_create_items (item_factory, G_N_ELEMENTS (groups_popup_menu_items),
-					       groups_popup_menu_items, (gpointer) groups_table);
-	return item_factory;
 }
 
 void
-create_gtk_tree_list (GtkWidget *list)
+create_gtk_tree_list (GtkWidget *list, GtkTargetEntry target)
 {
 	GtkTreeModel *model = GTK_TREE_MODEL(gtk_tree_store_new (2, G_TYPE_STRING, G_TYPE_POINTER));
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
-	
+	GtkTreeViewColumn *column;
+		
 	gtk_tree_view_set_model (GTK_TREE_VIEW (list), model);
+	g_object_unref (model);
 	
 	renderer = gtk_cell_renderer_text_new ();
-	
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (list),
-                                                     -1,
-                                                     "group",
-                                                     renderer,
-                                                     "text",
-                                                     0,
-                                                     NULL);
-	g_object_unref (model);
+
+	column = gtk_tree_view_column_new_with_attributes ("group",
+							   renderer,
+							   "text", 0,
+							   NULL);
+	gtk_tree_view_column_set_sort_column_id (column, 0);
+	gtk_tree_view_insert_column (GTK_TREE_VIEW (list), column, -1);
+
+	gtk_tree_view_column_clicked (column);
 	
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (list));
 	gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
+
+	g_signal_connect (G_OBJECT (selection),
+			  "changed",
+			  G_CALLBACK (on_list_select_row),
+			  NULL);
+	g_signal_connect (G_OBJECT (list),
+			  "drag-data-get",
+			  G_CALLBACK (on_list_drag_data_get),
+			  NULL);
+	g_signal_connect (G_OBJECT (list),
+			  "drag-data-received",
+			  G_CALLBACK (on_list_drag_data_received),
+			  NULL);
+
+	gtk_tree_view_enable_model_drag_source (GTK_TREE_VIEW (list),
+						GDK_BUTTON1_MASK,
+						&target, 1,
+						GDK_ACTION_MOVE);
+	gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (list),
+					      &target, 1,
+					      GDK_ACTION_MOVE);
+
+
 }
 
 void
@@ -142,6 +168,27 @@ populate_gtk_tree_list (GtkTreeView *list, GList *items)
 	}
 }
 
+GList*
+get_gtk_tree_list_items (GtkTreeView *list)
+{
+	GtkTreeModel *model = gtk_tree_view_get_model (list);
+	GtkTreeIter iter;
+	GList *item_list = NULL;
+	gchar *item;
+	gboolean valid;
+
+	valid = gtk_tree_model_get_iter_first (model, &iter);
+
+	while (valid) {
+		gtk_tree_model_get (model, &iter, 0, &item, -1);
+		item_list = g_list_prepend (item_list, item);
+
+		valid = gtk_tree_model_iter_next (model, &iter);
+	}
+
+	return item_list;
+}
+
 void
 create_tables (void)
 {
@@ -150,12 +197,6 @@ create_tables (void)
 	create_profiles_table ();
 }
 
-void 
-update_tables_complexity (GstDialogComplexity complexity) 
-{
-	update_users_table_complexity (complexity);
-}
-
 void
 populate_all_tables (void)
 {
