@@ -33,6 +33,7 @@
 #include <gnome.h>
 
 #include "gst.h"
+#include "gst-hig-dialog.h"
 #include "users-table.h"
 #include "table.h"
 #include "callbacks.h"
@@ -47,13 +48,6 @@ extern GstTool *tool;
 extern GList *groups_list;
 xmlNodePtr user_profile;
 
-static void
-create_groups_lists (xmlNodePtr node, GList **user_settings_all_list, GList **user_settings_members_list)
-{
-	*user_settings_members_list = user_get_groups (node);
-	*user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", NODE_GROUP), *user_settings_members_list);
-}
-
 static void
 create_groups_gtk_trees (void)
 {
@@ -62,24 +56,15 @@ create_groups_gtk_trees (void)
 	GtkWidget *add_button, *remove_button;
 	GtkTreeSelection *selection;
 	GtkSizeGroup *sizegroup = gtk_size_group_new (GTK_SIZE_GROUP_BOTH);
+	GtkTargetEntry target = { "group", GTK_TARGET_SAME_APP, 0 };
 	
 	/* connect signals and attach data if they haven't been created already */
 	if (g_object_get_data (G_OBJECT (user_settings_all), "button") == NULL) {
-		create_gtk_tree_list (user_settings_all);
+		create_gtk_tree_list (user_settings_all, target);
 		g_object_set_data (G_OBJECT (user_settings_all), "button", "user_settings_add");
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_all));
-		g_signal_connect (G_OBJECT (selection),
-		                  "changed",
-		                  G_CALLBACK (on_list_select_row),
-		                  NULL);
 
-		create_gtk_tree_list (user_settings_members);
+		create_gtk_tree_list (user_settings_members, target);
 		g_object_set_data (G_OBJECT (user_settings_members), "button", "user_settings_remove");
-		selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (user_settings_members));
-		g_signal_connect (G_OBJECT (selection),
-		                  "changed",
-		                  G_CALLBACK (on_list_select_row),
-		                  NULL);
 
 		/* We also need to attach some data to the 'add' and 'remove' buttons */
 		add_button = gst_dialog_get_widget (tool->main_dialog, "user_settings_add");
@@ -99,7 +84,7 @@ create_groups_gtk_trees (void)
 static gboolean
 check_user_delete (xmlNodePtr node)
 {
-	gchar *login, *buf;
+	gchar *login;
 	GtkWindow *parent;
 	GtkWidget *dialog;
 	gint reply;
@@ -109,32 +94,39 @@ check_user_delete (xmlNodePtr node)
 	parent = GTK_WINDOW (tool->main_dialog);
 	login = gst_xml_get_child_content (node, "login");
 
-	if (!login)
-	{
+	if (!login) {
 		g_warning ("check_user_delete: Can't get username");
 		return FALSE;
 	}
 
-	if (strcmp (login, "root") == 0)
-	{
-		buf = g_strdup (_("The root user must not be deleted."));
-		show_error_message ("user_settings_dialog", buf);
+	if (strcmp (login, "root") == 0) {
+		show_error_message ("user_settings_dialog",
+				    _("The \"root\" user should not be deleted"),
+				    _("This would leave the system unusable"));
 		g_free (login);
-		g_free (buf);
 		return FALSE;
 	}
 
-	buf = g_strdup_printf (_("Are you sure you want to delete user %s?"), login);
-	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL, GTK_MESSAGE_WARNING, GTK_BUTTONS_YES_NO, buf);
+	dialog = gst_hig_dialog_new (parent,
+				     GTK_DIALOG_MODAL,
+				     GST_HIG_MESSAGE_WARNING,
+				     NULL,
+				     "This will disable the access of this user to the system, "
+				     "but his home directory will not be deleted",
+				     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+				     GTK_STOCK_DELETE, GTK_RESPONSE_ACCEPT,
+				     NULL);
+	gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
+					 _("Are you sure you want to delete user \"%s\"?"), login);
+
 	reply = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
-	g_free (buf);
 	g_free (login);
-	
-	if (reply == GTK_RESPONSE_NO)
-		return FALSE;
-        else
+
+	if (reply == GTK_RESPONSE_ACCEPT)
 		return TRUE;
+        else
+		return FALSE;
 }
 
 gboolean
@@ -159,29 +151,49 @@ user_set_profile (xmlNodePtr profile)
 	gchar *buf;
 	ug_data *ud;
 	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
+
+	g_return_if_fail (profile != NULL);
 	
 	ud = g_object_get_data (G_OBJECT (widget), "data");
-	
-	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_home")),
-			    gst_xml_get_child_content (profile, "home_prefix"));
-	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")),
-			    gst_xml_get_child_content (profile, "shell"));
+
+	buf = gst_xml_get_child_content (profile, "home_prefix");
+	gtk_entry_set_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_home")), buf);
+	g_free (buf);
+
+	buf = gst_xml_get_child_content (profile, "shell");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"))->child), buf);
+	g_free (buf);
+
+	/* FIXME: this is hidden, will this section be ever necessary? */
+	gtk_widget_hide (gst_dialog_get_widget (tool->main_dialog, "user_optional_settings"));
+
+/*
+	buf = gst_xml_get_child_content (profile, "pwd_maxdays");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max")),
-				   g_strtod (gst_xml_get_child_content (profile, "pwd_maxdays"), NULL));
+				   g_strtod (buf, NULL));
+	g_free (buf);
+
+	buf = gst_xml_get_child_content (profile, "pwd_mindays");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min")),
-				   g_strtod (gst_xml_get_child_content (profile, "pwd_mindays"), NULL));
-	gtk_spin_button_set_value ( GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
-				   g_strtod (gst_xml_get_child_content (profile, "pwd_warndays"), NULL));
+				   g_strtod (buf, NULL));
+	g_free (buf);
+
+	buf = gst_xml_get_child_content (profile, "pwd_warndays");
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_days")),
+				   g_strtod (buf, NULL));
+	g_free (buf);
+*/
 
 	value = gst_xml_get_child_content (profile, "group");
 	element = g_list_first (groups_list);
 
-	while ((element != NULL) && (strcmp (element->data, value) != 0))
-	{
+	while ((element != NULL) && (strcmp (element->data, value) != 0)) {
 		element = element->next;
 		counter++;
 	}
-	gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")),
+				  counter);
 
 	/* Gets a new uid */
 	buf = (gchar *) find_new_id (ud->node, profile);
@@ -200,7 +212,6 @@ user_new_prepare (ug_data *ud)
 	GtkWidget *button;
 	gchar *buf;
 	GList *user_settings_all_list = NULL;
-	GList *user_settings_members_list = NULL;
 	GtkWidget *widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	GtkWidget *user_settings_all = gst_dialog_get_widget (tool->main_dialog, "user_settings_all");
 	GtkWidget *user_settings_members = gst_dialog_get_widget (tool->main_dialog, "user_settings_members");
@@ -212,17 +223,13 @@ user_new_prepare (ug_data *ud)
 	
 	/* Creates and fills GtkTrees */
 	create_groups_gtk_trees ();
-	create_groups_lists (ud->node, &user_settings_all_list, &user_settings_members_list);
+	user_settings_all_list = get_list_from_node ("name", NODE_GROUP);
 	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
 	
-	/* Attach the GLists to the GtkTreeViews */
-	g_object_set_data (G_OBJECT (user_settings_all), "list", user_settings_all_list);
-	g_object_set_data (G_OBJECT (user_settings_members), "list", user_settings_members_list);
-	
 	/* Fill menus */
-	option_menu_add_groups (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
-	combo_add_shells (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
-	option_menu_add_profiles (gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
+	combo_add_groups   (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"), TRUE);
+	combo_add_shells   (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"));
+	combo_add_profiles (gst_dialog_get_widget (tool->main_dialog, "user_settings_profile_menu"));
 
 #ifdef HAVE_LIBCRACK
 	/* If we have libcrack, password quality check is enabled */
@@ -283,15 +290,6 @@ user_settings_dialog_close (void)
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_notebook");
 	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 0);
 	
-	/* Clear the GLists attached to the GtkTreeViews */
-	list = g_object_get_data (G_OBJECT (user_settings_all), "list");
-	g_list_free (list);
-	g_object_steal_data (G_OBJECT (user_settings_all), "list");
-	
-	list = g_object_get_data (G_OBJECT (user_settings_members), "list");
-	g_list_free (list);
-	g_object_steal_data (G_OBJECT (user_settings_members), "list");
-
 	/* Clear user data attached to the widget */
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
 	ud = g_object_get_data (G_OBJECT (widget), "data");
@@ -300,7 +298,8 @@ user_settings_dialog_close (void)
 	gtk_widget_hide (widget);
 
 	/* Clear groups option menu */
-	gtk_option_menu_remove_menu (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")));
+	gtk_list_store_clear (GTK_LIST_STORE (model));
 }
 
 static gboolean
@@ -324,40 +323,56 @@ is_user_root (xmlNodePtr node)
 static gboolean
 is_login_valid (xmlNodePtr node, const gchar *login)
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 	struct utmp ut;
 
 	g_return_val_if_fail (node != NULL, FALSE);
 	g_return_val_if_fail (login != NULL, FALSE);
 
 	/* If !empty. */
-	if (strlen (login) < 1)
-		buf = g_strdup (_("The username is empty."));
+	if (strlen (login) < 1) {
+		primary_text = g_strdup (_("The user name is empty"));
+		secondary_text = g_strdup (_("A user name must be specified"));
+	}
 
 	/* If too long. */
 #ifdef __FreeBSD__
-	else if (strlen (login) > UT_NAMESIZE) /*  = sizeof (ut.ut_name) */
+	else if (strlen (login) > UT_NAMESIZE) { /*  = sizeof (ut.ut_name) */
+		primary_text   = g_strdup (_("The user name is too long"));
+		secondary_text = g_strdup_printf (_("The user name should have less than %i characters for being valid"), UT_NAMESIZE);
+	}
 #else
-	else if (strlen (login) > sizeof (ut.ut_user))
+	else if (strlen (login) > sizeof (ut.ut_user)) {
+		primary_text   = g_strdup (_("The user name is too long"));
+		secondary_text = g_strdup_printf (_("The user name should have less than %i characters for being valid"), sizeof (ut.ut_user));
+	}
 #endif
-		buf = g_strdup (_("The username is too long."));
-	
+
 	/* If user being modified is root */
-	else if ((is_user_root (node)) && (strcmp (login, "root") != 0))
-		buf = g_strdup (_("root username shouldn't be modified."));
+	else if ((is_user_root (node)) && (strcmp (login, "root") != 0)) {
+		primary_text   = g_strdup (_("User name for the \"root\" user should not be modified"));
+	        secondary_text = g_strdup (_("This would leave the system unusable"));
+	}
 
 	/* if valid. */
-	else if (!is_valid_name (login))
-		buf = g_strdup (_("Please set a valid username consisting of a lower case letter followed by lower case letters and numbers."));
+	else if (!is_valid_name (login)) {
+		primary_text   = g_strdup (_("User name has invalid characters"));
+		secondary_text = g_strdup (_("Please set a valid user name consisting of "
+					     "a lower case letter followed by lower case letters and numbers"));
+	}
 
 	/* if !exist. */
-	else if (node_exists (node, "login", login))
-		buf = g_strdup_printf (_("Username \"%s\" already exists.\n\nPlease select a different Username"), login);
+	else if (node_exists (node, "login", login)) {
+		primary_text   = g_strdup_printf (_("User name \"%s\" already exists"), login);
+		secondary_text = g_strdup (_("Please select a different user name"));
+	}
 
 	/* If anything is wrong. */
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", primary_text, secondary_text);
+		g_free (primary_text);
+		g_free (secondary_text);
 
 		return FALSE;
 	} else {
@@ -369,20 +384,23 @@ static gboolean
 is_comment_valid (gchar *name, gchar *location, gchar *wphone, gchar *hphone)
 {
 	gchar *comment = g_strjoin (" ", name, location, wphone, hphone, NULL);
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 	gint i;
 	
 	for (i = 0; i < strlen (comment); i++) {
 		if (iscntrl (comment[i]) || comment[i] == ',' || comment[i] == '=' || comment[i] == ':') {
-			buf = g_strdup_printf (N_("Invalid character '%c' in comment."), comment[i]);
+			primary_text   = g_strdup_printf (N_("Invalid character \"%c\" in comment"), comment[i]);
+			secondary_text = g_strdup (N_("Check that this character is not used"));
 			break;
 		}
 	}
 	g_free (comment);
 
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", _(primary_text), _(secondary_text));
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	} else {
@@ -416,31 +434,36 @@ parse_user_home (gchar *old_home, gchar *name)
 static gboolean
 is_home_valid (xmlNodePtr node, gchar *home)
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 	struct stat s;
 	
-	if (!home || (strlen (home) < 1))
-		buf = g_strdup (N_("Home directory must not be empty."));
-
-	else if (*home != '/')
-		buf = g_strdup (N_("Please enter full path for home directory."));
-	
-	else if ((is_user_root (node)) && (strcmp (home, "/root") != 0))
-		buf = g_strdup (_("root home shouldn't be modified."));
+	if (!home || (strlen (home) < 1)) {
+		primary_text   = g_strdup (N_("Home directory should not be empty"));
+		secondary_text = g_strdup (N_("Make sure you provide a home directory"));
+	} else if (*home != '/') {
+		primary_text   = g_strdup (N_("Incomplete path in home directory"));
+		secondary_text = g_strdup (N_("Please enter full path for home directory\n"
+					      "<span size=\"smaller\">i.e.: /home/john</span>"));
+	} else if ((is_user_root (node)) && (strcmp (home, "/root") != 0)) {
+		primary_text   = g_strdup (N_("Home directory of the \"root\" user should not be modified"));
+		secondary_text = g_strdup (N_("This would leave the system unusable"));
+	}
 
 /*	else if (stat (home, &s))
 	{
 		switch (errno) {
-		case ENOTDIR: buf = g_strdup (_("Part of the path to the home directory is a file."));
-		case ELOOP:   buf = g_strdup (_("There is a loop in the path to the home directory."));
-		case ENOMEM:  buf = g_strdup (_("Not enough memory to check the home directory."));
-		case ENAMETOOLONG: buf = g_strdup (_("The path to the home directory is too long."));
+		case ENOTDIR: buf = g_strdup (_("Part of the path to the home directory is a file"));
+		case ELOOP:   buf = g_strdup (_("There is a loop in the path to the home directory"));
+		case ENOMEM:  buf = g_strdup (_("Not enough memory to check the home directory"));
+		case ENAMETOOLONG: buf = g_strdup (_("The path to the home directory is too long"));
 		}
 	}
 */
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", _(primary_text), _(secondary_text));
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	} else {
@@ -451,22 +474,41 @@ is_home_valid (xmlNodePtr node, gchar *home)
 static gboolean
 is_user_uid_valid (xmlNodePtr node, const gchar *uid)
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
+	GtkWidget *dialog;
 
-	if (!is_valid_id (uid))
-		buf = g_strdup (_("User id must be a positive number."));
-	else if ((is_user_root (node)) && (strcmp (uid, "0") != 0))
-		buf = g_strdup (_("root uid shouldn't be modified."));
-	else if (node_exists (node, "uid", uid)) {
-		buf = g_strdup (_("Such user id already exists."));
+	if (!is_valid_id (uid)) {
+		primary_text   = g_strdup (N_("Invalid user ID"));
+		secondary_text = g_strdup (N_("User ID must be a positive number"));
+	} else if ((is_user_root (node)) && (strcmp (uid, "0") != 0)) {
+		primary_text   = g_strdup (N_("User ID of the \"root\" user should not be modified"));
+		secondary_text = g_strdup (N_("This would leave the system unusable"));
 	}
 	
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", _(primary_text), _(secondary_text));
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	} else {
+		if (node_exists (node, "uid", uid)) {
+			dialog = gst_hig_dialog_new (GTK_WINDOW (gst_dialog_get_widget (tool->main_dialog,
+											"user_settings_dialog")),
+						     GTK_DIALOG_MODAL,
+						     GST_HIG_MESSAGE_INFO,
+						     NULL,
+						     _("Several users may share a single user ID, "
+						       "but it's not common and may lead to security problems"),
+						     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+						     NULL);
+			gst_hig_dialog_set_primary_text (GST_HIG_DIALOG (dialog),
+							 _("User ID %s already exists"), uid);
+			gtk_dialog_run (GTK_DIALOG (dialog));
+			gtk_widget_destroy (dialog);
+		}
+
 		return TRUE;
 	}
 }
@@ -475,14 +517,19 @@ is_user_uid_valid (xmlNodePtr node, const gchar *uid)
 static gboolean
 is_shell_valid (const gchar *val)
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
+	
+	if (strlen (val) > 0 && *val != '/') {
+		primary_text   = g_strdup (N_("Incomplete path in shell"));
+		secondary_text = g_strdup (N_("Please enter full path for shell\n"
+					      "<span size=\"smaller\">i.e.: /bin/sh</span>"));
+	}
 
-	if (strlen (val) > 0 && *val != '/')
-		buf = g_strdup (_("Please give shell with full path."));
-
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", _(primary_text), _(secondary_text));
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	} else {
@@ -493,17 +540,21 @@ is_shell_valid (const gchar *val)
 static gboolean
 is_password_valid (const gchar *passwd1, const gchar *passwd2) 
 {
-	gchar *buf = NULL;
+	gchar *primary_text   = NULL;
+	gchar *secondary_text = NULL;
 	
-	if (!passwd1 || !passwd2 || strlen (passwd1) < 1 || strlen (passwd2) < 1)
-		buf = g_strdup (_("Password must not be empty."));
-	
-	else if (strcmp (passwd1, passwd2) != 0)
-		buf = g_strdup (_("Password confirmation isn't correct."));
+	if (!passwd1 || !passwd2 || strlen (passwd1) < 1 || strlen (passwd2) < 1) {
+		primary_text   = g_strdup (N_("Password should not be empty"));
+		secondary_text = g_strdup (N_("A password must be provided"));
+	} else if (strcmp (passwd1, passwd2) != 0) {
+		primary_text   = g_strdup (N_("Password confirmation isn't correct"));
+		secondary_text = g_strdup (N_("Check that you have provided the same password in both text fields"));
+	}
 
-	if (buf) {
-		show_error_message ("user_settings_dialog", buf);
-		g_free (buf);
+	if (primary_text) {
+		show_error_message ("user_settings_dialog", _(primary_text), _(secondary_text));
+		g_free (primary_text);
+		g_free (secondary_text);
 		
 		return FALSE;
 	} else {
@@ -571,7 +622,7 @@ user_update (ug_data *ud)
 	}
 	
 	/* check user shell */
-	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry")));
+	data->shell = (gchar *) gtk_entry_get_text (GTK_ENTRY (GTK_BIN (gst_dialog_get_widget (tool->main_dialog, "user_settings_shell"))->child));
 	if (!is_shell_valid (data->shell)) {
 		return FALSE;
 	}
@@ -606,17 +657,16 @@ user_update (ug_data *ud)
 	}
 
 	/* get user main group GID*/
-	data->group = g_list_nth_data (groups_list, gtk_option_menu_get_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
+	data->group = g_list_nth_data (groups_list, gtk_combo_box_get_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group"))));
 	if (strcmp (data->group, "$user") == 0)
 		data->group = data->login;
 	
 	data->gid = group_check (ud->node, data->group);
-	if (!data->gid) {
+	if (!data->gid)
 		return FALSE;
-	}
 
 	g_list_free (data->extra_groups);
-	data->extra_groups = g_list_copy (g_object_get_data (G_OBJECT (user_settings_members), "list"));
+	data->extra_groups = get_gtk_tree_list_items (GTK_TREE_VIEW (user_settings_members));
 
 	data->pwd_maxdays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_max"))));
 	data->pwd_mindays = g_strdup_printf ("%i", gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (gst_dialog_get_widget (tool->main_dialog, "user_passwd_min"))));
@@ -722,56 +772,55 @@ user_settings_dialog_prepare (ug_data *ud)
 	/* Set shells combo */
 	combo_add_shells (combo);
 	txt = gst_xml_get_child_content (ud->node, "shell");
-	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell_entry");
-	gst_ui_entry_set_text (w0, txt);
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_shell");
+	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (w0)->child), txt);
 	g_free (txt);
 	
 	/* set main group option menu */
-	option_menu_add_groups (option_menu, FALSE);
+	combo_add_groups (option_menu, FALSE);
 	txt = get_group_name (gst_xml_get_child_content (ud->node, "gid"));
 
 	if (txt != NULL) {
 		element = g_list_first (groups_list);
 
-		while ((element != NULL) && (strcmp (element->data, txt) != 0))
-		{
+		while ((element != NULL) && (strcmp (element->data, txt) != 0))	{
 			element = element->next;
 			counter++;
 		}
-		gtk_option_menu_set_history (GTK_OPTION_MENU (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
+		gtk_combo_box_set_active (GTK_COMBO_BOX (gst_dialog_get_widget (tool->main_dialog, "user_settings_group")), counter);
 		g_free (txt);
 	}
 	
 	/* Fill groups lists */
 	create_groups_gtk_trees ();
-	create_groups_lists (ud->node, &user_settings_all_list, &user_settings_members_list);
+
+	user_settings_members_list = user_get_groups (ud->node);
+	user_settings_all_list = my_g_list_remove_duplicates (get_list_from_node ("name", NODE_GROUP), user_settings_members_list);
 	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_all), user_settings_all_list);
 	populate_gtk_tree_list (GTK_TREE_VIEW (user_settings_members), user_settings_members_list);
 	
-	/* Attach the GLists to the GtkTreeViews */
-	g_object_set_data (G_OBJECT (user_settings_all), "list", user_settings_all_list);
-	g_object_set_data (G_OBJECT (user_settings_members), "list", user_settings_members_list);
-	
 	/* Set password */
 	user_settings_dialog_prepare_password ();
-	
-	/* Set maxdays */
-	txt = gst_xml_get_child_content (ud->node, "passwd_max_life");
+
+	/* FIXME: This is hidden, will this section be ever necessary? */
+	w0 = gst_dialog_get_widget (tool->main_dialog, "user_optional_settings");
+	gtk_widget_hide (w0);
+
+/*
 	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_max");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
-	/* Set mindays */
 	txt = gst_xml_get_child_content (ud->node, "passwd_min_life");
 	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_min");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
 	
-	/* Set warndays */
 	txt = gst_xml_get_child_content (ud->node, "passwd_exp_warn");
 	w0 = gst_dialog_get_widget (tool->main_dialog, "user_passwd_days");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w0), g_strtod (txt, NULL));
 	g_free (txt);
+*/
 	
 	/* Set window title */
 	w0 = gst_dialog_get_widget (tool->main_dialog, "user_settings_dialog");
